.. math::
    \operatorname{prox}_{\rho f}(\mathbf{y})
    = \arg\min_{\mathbf{x}}  \left\{ f(\mathbf{x}) + \frac{1}{2\rho} \| \mathbf{x} - \mathbf{y} \|^2 \right\}

where :math:`\rho > 0` is the penalty and :math:`f` the cost function.
